
# THIS FILE IS GENERATED FROM SCIPY SETUP.PY
short_version = '0.0.8'
version = '0.0.8'
full_version = '0.0.8'
git_revision = 'aab9617a521b74731ae6564d4733475828949e9f'
release = True
if not release:
    version = full_version
